@@ -185,7 +185,7 @@ run_event_job = '''
 
 create_notification = '''
 mutation CreateNotification(
-  $userId: Int
+  $userId: ID
   $context: NotificationType,
   $title: String,
   $content: Text,
