@@ -2,6 +2,7 @@ import pydash as __
 from pprint import pformat
 import time
 import json
+from typing import Callable, Dict
 from json.decoder import JSONDecodeError
 import multiprocessing as mp
 from multiprocessing import SimpleQueue, Pipe
@@ -82,7 +83,7 @@ def safe_pop(data, index=0, default=None):
 @singleton
 class ValiotWorker():
     """The ValiotWorker class follows the singleton design pattern. It
-      manages all listener logic for any action of a Graphql schema for many queues. 
+      manages all listener logic for any action of a Graphql schema for many queues.
 
       Attributes:
           queues (dict): Dictonary with all queues. Defaults to
@@ -187,7 +188,7 @@ class ValiotWorker():
         self.worker_code = worker
 
     def setPollingMode(self, mode):
-        """Sets Polling Mode 
+        """Sets Polling Mode
 
         Args:
             mode (PollingMode): PollingMode option.
@@ -247,7 +248,7 @@ class ValiotWorker():
             notificationFrequency (str, optional): Notification frequency Defaults to ''.
             notificationSchedule (str, optional): Notification Schedule in cron like
               format. Defaults to ''.
-            eventConfig (optional): Event configuration. Defaults to 
+            eventConfig (optional): Event configuration. Defaults to
               DEFAULT_EVENT_CONFIG.
         """
         def wrap(f):
@@ -516,7 +517,9 @@ class ValiotWorker():
         # ! Validates existence of requested job for this worker:
         if not job_dict:
             self.log(
-                LogLevel.ERROR, f"{fn_name} job not found (it might exist in another branch / parallel universe), skipping...")
+                LogLevel.ERROR,
+                f"{fn_name} job not found (it might exist in another branch / parallel universe), skipping..."
+            )
             # TODO: Here we can update the job to aborted or something
             return
         self.log(LogLevel.INFO, f"running {fn_name}")
@@ -631,7 +634,7 @@ class ValiotWorker():
             queue_name (string): Queue's name
 
         Returns:
-            boolean/object: Returns the information of the locked object. 
+            boolean/object: Returns the information of the locked object.
         """
         queues_by_name = __.group_by(self.currentQueues, 'name')
         current_queue = __.get(queues_by_name, f'{queue_name}.0')
@@ -641,7 +644,7 @@ class ValiotWorker():
         return __.get(current_queue, 'locks.0.active')
 
     def workerQueueEnabled(self, queue):
-        """This function checks if the queue is enable. 
+        """This function checks if the queue is enable.
 
         Args:
             queue (object): Queue object
@@ -1038,34 +1041,44 @@ class ValiotWorker():
             })
         return True
 
+    def getOnQueueEventCallback(self, queue: Dict[str, str]) -> Callable:
+        """Wrap the onEventTriggered with a given queue data estructure for labeling purposes
+
+        Args:
+            queue (Dict[str, str]): Data structure returned by self.queues
+        """
+        def onEventTriggered(data):
+            """Callback to execute on every event triggered of the same type.
+            This callback performs a check to know if enough data (or time)
+            has elapsed and thus the Job has to be executed with the current chunk of data
+
+            Parameters
+            ----------
+            data : any
+                Data received from the event
+            """
+            if not self.workerQueueEnabled(queue):
+                return  # Skipping event
+            if len(self.eventQueues[queue["name"]]["mailbox"]) == 0:
+                self.log(
+                    LogLevel.WARNING, f'EVENT { queue["name"] } TRIGGERED, BUILDING BATCH')
+                self.eventQueues[queue["name"]]["start_time"] = time.time()
+            self.eventQueues[queue["name"]]["mailbox"].append(data)
+            if len(self.eventQueues[queue["name"]]["mailbox"]) >= self.eventQueues[queue["name"]]['config'][
+                    'max_batch']:
+                """Run event only if event surpassed the upper data limit"""
+                self.runEvent(queue["name"])
+        return onEventTriggered
+
     def registerEventJobs(self):
         """This function registers a new event job.
         """
         queuesByType = __.group_by(self.queues.values(), 'type')
         eventQueues = __.get(queuesByType, 'EVENT', default=[])
         for queue in eventQueues:
-            def onEventTriggered(data):
-                """Callback to execute on every event triggered of the same type.
-                This callback performs a check to know if enough data (or time)
-                has elapsed and thus the Job has to be executed with the current chunk of data
-
-                Parameters
-                ----------
-                data : any
-                    Data received from the event
-                """
-                if not self.workerQueueEnabled(queue):
-                    return  # Skipping event
-                if len(self.eventQueues[queue["name"]]["mailbox"]) == 0:
-                    self.log(
-                        LogLevel.WARNING, f'EVENT { queue["name"] } TRIGGERED, BUILDING BATCH')
-                    self.eventQueues[queue["name"]]["start_time"] = time.time()
-                self.eventQueues[queue["name"]]["mailbox"].append(data)
-                if len(self.eventQueues[queue["name"]]["mailbox"]) >= self.eventQueues[queue["name"]]['config']['max_batch']:
-                    """Run event only if event surpassed the upper data limit"""
-                    self.runEvent(queue["name"])
             unsub = self.gql.subscribe(
-                query=queue['query'], callback=onEventTriggered)
+                query=queue['query'],
+                callback=self.getOnQueueEventCallback(queue))
             if (unsub):
                 self.log(
                     LogLevel.SUCCESS, f'REGISTERED LISTENER FOR EVENT QUEUE { queue["name"] }')
@@ -1098,7 +1111,7 @@ class ValiotWorker():
                      f'ERROR REGISTERING LISTENER FOR JOB UPDATES')
 
     def registerContinuousJobs(self):
-        """This function registers for all continues jobs. 
+        """This function registers for all continues jobs.
         """
         queuesByType = __.group_by(self.queues.values(), 'type')
         shedeuleQueues = __.get(queuesByType, 'CONTINUOUS', default=[])
@@ -1125,7 +1138,7 @@ class ValiotWorker():
                             mutations.update_lock, variables)
                         if errors:
                             self.log(LogLevel.ERROR,
-                                    f'Error update_lock:\n{errors}')
+                                     f'Error update_lock:\n{errors}')
 
         if self.continuousJobs:
             self.log(LogLevel.SUCCESS, 'REGISTERED Continuous Queues:')
